import _extends from "@babel/runtime/helpers/esm/extends";
import { stringify } from 'qs';

/**
 * converts query params object to query string
 *
 * @param {object} queryParams
 * @param {object} [options={}]
 * @param {'indices'|'brackets'|'repeat'|'comma'} [options.arrayFormat] - specify the format of the output array
 * @param {string} [options.delimiter] - delimiter
 * @param {boolean} [options.encode=true] - encode
 * @param {boolean} [options.addQueryPrefix=false] - add question mark query prefix
 * @param {boolean} [options.skipNulls=false] - skip null values
 */
function toQueryString(queryParams, options) {
  if (options === void 0) {
    options = {};
  }
  var _options = options,
    _options$addQueryPref = _options.addQueryPrefix,
    addQueryPrefix = _options$addQueryPref === void 0 ? false : _options$addQueryPref,
    arrayFormat = _options.arrayFormat,
    delimiter = _options.delimiter,
    _options$encode = _options.encode,
    encode = _options$encode === void 0 ? true : _options$encode,
    _options$skipNulls = _options.skipNulls,
    skipNulls = _options$skipNulls === void 0 ? false : _options$skipNulls;
  var mergedOptions = _extends({
    addQueryPrefix: addQueryPrefix,
    encode: encode,
    skipNulls: skipNulls
  }, typeof arrayFormat !== 'undefined' && {
    arrayFormat: arrayFormat
  }, typeof delimiter !== 'undefined' && {
    delimiter: delimiter
  });
  return stringify(queryParams, mergedOptions);
}
export default toQueryString;